@@ -1,6 +1,6 @@
 {- git-annex repository versioning
  -
- - Copyright 2010 Joey Hess <joey@kitenet.net>
+ - Copyright 2010,2013 Joey Hess <joey@kitenet.net>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
@@ -9,14 +9,18 @@ module Annex.Version where
 
 import Common.Annex
 import Config
+import qualified Annex
 
 type Version = String
 
 defaultVersion :: Version
 defaultVersion = "3"
 
+directModeVersion :: Version
+directModeVersion = "4"
+
 supportedVersions :: [Version]
-supportedVersions = [defaultVersion]
+supportedVersions = [defaultVersion, directModeVersion]
 
 upgradableVersions :: [Version]
 upgradableVersions = ["0", "1", "2"]
@@ -25,13 +29,10 @@ versionField :: ConfigKey
 versionField = annexConfig "version"
 
 getVersion :: Annex (Maybe Version)
-getVersion = handle <$> getConfig versionField ""
-	where
-		handle [] = Nothing
-		handle v = Just v
+getVersion = annexVersion <$> Annex.getGitConfig
 
-setVersion :: Annex ()
-setVersion = setConfig versionField defaultVersion
+setVersion :: Version -> Annex ()
+setVersion = setConfig versionField
 
 removeVersion :: Annex ()
 removeVersion = unsetConfig versionField
@@ -41,6 +42,6 @@ checkVersion v
 	| v `elem` supportedVersions = noop
 	| v `elem` upgradableVersions = err "Upgrade this repository: git-annex upgrade"
 	| otherwise = err "Upgrade git-annex."
-	where
-		err msg = error $ "Repository version " ++ v ++
-			" is not supported. " ++ msg
+  where
+	err msg = error $ "Repository version " ++ v ++
+		" is not supported. " ++ msg
